@@ -1,7 +1,8 @@
 "t.trellis" <- function(x) {
   if.R(
        r={
-         lattice:::t.trellis(x)
+         ## lattice:::t.trellis(x)
+         lattice.t.trellis(x)
        },s={
          names.x <- names(x)
          n.x.index <-
@@ -16,9 +17,9 @@
          n.x.s[nxsx] <- "y"
          n.x.s[nxsy] <- "x"
          names(x$scales) <- n.x.s
-         
+
          x$labs[1:2] <- x$labs[2:1]
-         
+
          if (is.function(x$panel)) {
            warning("x$panel is a function, this transpose may not work correctly.")
            if (is.null(x$transpose))
@@ -27,7 +28,7 @@
              x$transpose <- !x$transpose
            return(x)
          }
-         
+
          if (x$panel=="panel.bwplot.intermediate.hh" ||
              x$panel=="panel.bwplott" ||
              x$panel=="panel.barchartt" ||
@@ -40,27 +41,27 @@
            else
              x$transpose <- !x$transpose
          }
-         
+
          if (x$panel=="panel.bwplot") {
            x$panel <- "panel.bwplott"
            x$transpose <- TRUE
          }
-         
+
          if (x$panel=="panel.barchart") {
            x$panel <- "panel.barchartt"
            x$transpose <- TRUE
          }
-         
+
          if (x$panel=="panel.dotplot") {
            x$panel <- "panel.dotplott"
            x$transpose <- TRUE
          }
-         
+
          if (x$panel=="panel.histogram") {
            x$panel <- "panel.histogram.hh"
            x$transpose <- TRUE
          }
-         
+
          x
        })
 }
